# snake_eyes
## about
snake_eyes is a python library to make simple the intricate world of random variable algebra. It features many advanced tools to help users create any kind of distribution they desire.